@@ -1,9 +1,9 @@
-version = '0.0.23'
+version = '0.0.26'
 from .table import Datable
 import os, sys
 start_des = '''
  -------------------------------------------------------------------------------------------------------------
- |                                         Datable By Ziplux                                                 |
+ |                                                                                                           |
  -------------------------------------------------------------------------------------------------------------
                *******          *     ************     *          *******      ***          ********
               *********       ***         **         ***         ***    **    ***          ***
@@ -12,7 +12,9 @@ start_des = '''
            ***    ***   *********      **      *********      ***    **    ***          ***
           *********   ***      **     **     ***      **     ***    ***   ***          ***
          *******    ***        **    **    ***        **    *********    *********    *********   
-         Version: {}
+         By Ziplux     Version: {}     
+ -------------------------------------------------------------------------------------------------------------
+ |                                                                                                           |
  -------------------------------------------------------------------------------------------------------------'''.format(version.replace("'",''))
 
 print(start_des)
\ No newline at end of file
